@@ -30,8 +30,8 @@ if test -z "${2}"; then
             if test -d "${theme_name}"; then
                 theme_path="${theme_dir}/${theme_name}"
                 echo "Entry = \"${theme_name}\" { Actions = \"Exec ${0} ${1} ${theme_path}\" }"
-                for theme_variant in `ls ${theme_path}/theme-* 2>/dev/null | grep -v '~'`; do
-                    variant=`basename ${theme_variant} | sed 's/theme-//'`
+                for theme_variant in `ls ${theme_path}/theme-* 2>/dev/null | /bin/grep -v '~'`; do
+                    variant=`basename ${theme_variant} | /bin/sed 's/theme-//'`
                     echo "Entry = \"${theme_name} (${variant})\" { Actions = \"Exec ${0} ${1} ${theme_path} ${variant}\" }"
                 done
             fi
@@ -49,7 +49,7 @@ else
         exit 1;
     fi
 
-    theme=`echo "${2}" | /usr/bin/sed -e "s@^${HOME}@~@" | /usr/bin/sed -e 's@\/@\\\/@g'`
+    theme=`echo "${2}" | /bin/sed -e "s@^${HOME}@~@" | /bin/sed -e 's@\/@\\\/@g'`
     variant="${3}"
 
     # Get temporary file, not all platforms have mktemp though
@@ -67,14 +67,14 @@ else
     qq='\"'
     text='[Tt][Hh][Ee][Mm][Ee]'
 
-    /usr/bin/sed -e "/^\([^#]*\)ThemeVariant/d" \
+    /bin/sed -e "/^\([^#]*\)ThemeVariant/d" \
      -e "s/^\([^#]*\)$text$wspc=$wspc$qq[^$qq]*$qq/\1Theme\2=\3$qq${theme}$qq@    ThemeVariant = $qq${variant}$qq/" \
      "${PEKWM_CONFIG_FILE}" \
      | tr '@' '\n' > "${tmp_file}"
     mv "${tmp_file}" "${PEKWM_CONFIG_FILE}"
 
     # Reload pekwm
-    kill -HUP `xprop -root _NET_WM_PID | awk '/_NET_WM_PID/ { print $3 }'`
+    kill -HUP `xprop -root _NET_WM_PID | /usr/bin/gawk '/_NET_WM_PID/ { print $3 }'`
 fi
 
 exit 0
